DashboardBundleRef class

Reference used to locate a dashboard bundle (MOD-MODEL-004).

Distinct from the BundleRef in src/bundle/ (which points to an mcp_bundle.McpBundle application). A DashboardBundleRef references the dashboard-only schema that Dashboard Mode composes.

Constructors

DashboardBundleRef({required String bundleId, required BundleSource source, String? url, String? aggregatorServerId, Map<String, dynamic>? inlineDefinition})
const

Properties

aggregatorServerId String?
final
bundleId String
final
hashCode int
The hash code for this object.
no setterinherited
inlineDefinition Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source BundleSource
final
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited