NoopMetricsPort class

Implemented types

Constructors

NoopMetricsPort()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordCount(String metric, {int value = 1, Map<String, String>? tags}) → void
override
recordError(String operation, String errorType, {Map<String, String>? tags}) → void
override
recordLatency(String operation, Duration duration, {Map<String, String>? tags}) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited