SlotDefinition class

Declaration of a single dashboard slot.

Constructors

SlotDefinition({required String slotId, required SlotBindingRule binding, String? summaryUri, Map<String, dynamic>? filter})
const
SlotDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

binding SlotBindingRule
final
filter Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slotId String
final
summaryUri String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited