TenantContext class

Resolved tenant context (MOD-MODEL-003).

Constructors

TenantContext({required String appCode, required Set<String> allowedServerIds, required Set<String> allowedBundleIds, Map<String, dynamic> branding = const {}, Map<String, dynamic> policies = const {}})
const

Properties

allowedBundleIds Set<String>
final
allowedServerIds Set<String>
final
appCode String
final
branding Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
policies Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited