captureKey property
Key for the RepaintBoundary the host wraps the rendered app in.
The capture / layout primitives read the render object off this key.
Implementation
final GlobalKey captureKey = GlobalKey();
Key for the RepaintBoundary the host wraps the rendered app in.
The capture / layout primitives read the render object off this key.
final GlobalKey captureKey = GlobalKey();