JsToolRuntime class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attachHostBridge(
{required Iterable< AtomCategory> atoms, required Iterable<String> allowedAtoms}) → Future<void> -
Attach the host bridge. Atoms allowed by
allowedAtomsare surfaced inside the worker'shost.*. Theatomslist provides the verb names + the live atom instances the dispatcher will invoke. -
dispose(
) → Future< void> -
evaluate(
String code, {String? sourceUrl}) → Future< JsEvalResult> -
evaluateAsync(
String code, {String? sourceUrl}) → Future< JsEvalResult> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited