failed property
Resources whose subscribe was refused or threw. The stream for these is still dead after the reattach.
Implementation
final int failed;
Resources whose subscribe was refused or threw. The stream for these is still dead after the reattach.
final int failed;