isTotalFailure property
bool
get
isTotalFailure
True when the reattach had work to do and none of it landed.
Implementation
bool get isTotalFailure => resubscribed == 0 && failed > 0;
True when the reattach had work to do and none of it landed.
bool get isTotalFailure => resubscribed == 0 && failed > 0;