ResolvedBundleUri class

Resolved target for a bundle:// URI (MOD-BUNDLE-003).

Constructors

ResolvedBundleUri(Uri target, String mediaType)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mediaType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited