SummaryViewResolver class

Locates and parses a device's summary view definition (MOD-DASH-004, FR-DASH-005~006).

Constructors

SummaryViewResolver({Logger? logger})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetch(Client client, {String? customUri}) Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited