TransportFactory class
Translates ServerConfig into an mcp_client.TransportConfig
(MOD-CONN-002, FR-CONN-009).
Adding a new transport type requires changing only this module (NFR-EXT-004).
Constructors
- TransportFactory()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
ServerConfig server) → TransportConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited