ApplicationDefinition class
Constructors
-
ApplicationDefinition({required Map<
String, dynamic> json, required PageLoaderFn pageLoader, required ApplicationSourceKind sourceKind, String? appId}) -
const
Properties
- appId → String?
-
serverIdfor Online,bundle.manifest.idfor Local Bundle.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
json
→ Map<
String, dynamic> -
JSON payload accepted by
MCPUIRuntime.initialize.final - pageLoader → PageLoaderFn
-
Page loader closure for lazy route resolution.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceKind → ApplicationSourceKind
-
Provenance label.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited