AtomVerb class
One verb declared by an AtomCategory. The bridge turns each verb
into a JS function on the atom's host.<key> object.
Properties
- description → String?
-
Optional human-readable description for diagnostic / docs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
JS function name. Becomes
host.<atomKey>.<name>.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited