BundleResolver class
Parses BundleManifest.entryPoint and validates type/entry compatibility
(MOD-BUNDLE-002, FR-BUNDLE-002 / FR-APP-LOCAL-002~003).
Constructors
- BundleResolver()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
assertApplicationType(
McpBundle bundle) → void - FR-APP-LOCAL-002
-
assertUiEntry(
BundleEntryPoint entry, {required String bundleId}) → void - FR-APP-LOCAL-003
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveEntry(
McpBundle bundle) → BundleEntryPoint - FR-BUNDLE-002
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited