BundleUriResolver class
Resolves bundle:// URIs into runtime-consumable URIs (MOD-BUNDLE-003,
FR-BUNDLE-003 / FR-APP-LOCAL-005, UI DSL v1.2 5.3).
Constructors
- BundleUriResolver({String? bundleRootPath, AssetSection? assets, Logger? logger})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
String bundleUri) → ResolvedBundleUri - FR-BUNDLE-003
-
rewriteDefinition(
dynamic node) → dynamic -
Recursively rewrites
bundle://strings inside a definition JSON tree. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited