ConnectionManager class
Manages MCP server connections: create, reuse, disconnect, reconnect, and notify listeners on state changes (MOD-CONN-001, FR-CONN-001~010).
- Inheritance
-
- Object
- ChangeNotifier
- ConnectionManager
Constructors
- ConnectionManager({Logger? logger, TransportFactory? transportFactory, ClientConnector? connector, Duration? waitCheckInterval, Duration? waitMaxDuration})
Properties
-
connections
→ Map<
String, ConnectionInfo> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
connect(
ServerConfig server) → Future< ConnectionResult> - FR-CONN-001~003, 010
-
disconnect(
String serverId) → Future< void> - FR-CONN-004
-
disconnectAll(
) → Future< void> - FR-CONN-005
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
getConnection(
String serverId) → ConnectionInfo? -
hasConnection(
String serverId) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
reconnect(
String serverId) → Future< ConnectionResult> - FR-CONN-006
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited