JsEvalResult class
Result of an evaluate / evaluateAsync call — wraps the
JSON-serialized return value from the worker. Mirrors the subset
of flutter_js.JsEvalResult callers actually consume.
Constructors
- JsEvalResult({required String stringResult, required bool isError})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringResult → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited