RuntimeManager class
Owns the lifecycle of per-AppHandle MCPUIRuntime instances
(MOD-RUNTIME-001, FR-RUNTIME-001~004).
Keying on AppHandle separates server: and bundle: namespaces so the
same id string cannot collide across sources (FR-SESSION-006).
- Inheritance
-
- Object
- ChangeNotifier
- RuntimeManager
Constructors
- RuntimeManager({Logger? logger})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
runtimes
→ Map<
AppHandle, MCPUIRuntime> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
getOrCreateRuntime(
AppHandle handle) → MCPUIRuntime - FR-RUNTIME-001
-
getRuntime(
AppHandle handle) → MCPUIRuntime? -
hasRuntime(
AppHandle handle) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeAllRuntimes(
) → Future< void> - FR-RUNTIME-004
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeRuntime(
AppHandle handle) → Future< void> - FR-RUNTIME-003
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited