TenantResolver class
Resolves app codes into TenantContext and guards allowlists (MOD-TENANT-001, FR-TENANT-001~006).
Constructors
- TenantResolver({TenantSource? source, Logger? logger})
Properties
- current → TenantContext?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
String appCode) → Future< TenantContext> - FR-TENANT-001, 002
-
assertAllowedBundle(
String bundleId) → void - FR-TENANT-004
-
assertAllowedServer(
String serverId) → void - FR-TENANT-003
-
clear(
) → void - FR-TENANT-005
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited